@@ -1,4 +1,6 @@
 import torchvision
+import numpy as np
+import torch
 import sys
 
 
@@ -11,6 +13,15 @@ from lightwood.mixers import BUILTIN_MIXERS
 from lightwood.api.predictor import Predictor
 import lightwood.model_building
 import lightwood.constants.lightwood as CONST
+from lightwood.helpers.device import get_devices
 
 
 COLUMN_DATA_TYPES = CONST.COLUMN_DATA_TYPES
+
+# fix random seed for reproducibility
+seed = 42
+np.random.seed(seed)
+torch.manual_seed(seed)
+if 'cuda' in str(get_devices()[0]):
+    torch.backends.cudnn.deterministic = True
+    torch.backends.cudnn.benchmark = False
\ No newline at end of file
