@@ -3,3 +3,5 @@ from lightwood.encoders.text.infersent import InferSentEncoder
 from lightwood.encoders.text.distilbert import DistilBertEncoder
 from lightwood.encoders.text.tfidf import TfidfEncoder
 from lightwood.encoders.text.short import ShortTextEncoder
+from lightwood.encoders.text.flair import FlairEmbeddingEncoder
+from lightwood.encoders.text.vocab import VocabularyEncoder
